==> owncloud_7.0.4+dfsg.orig.tar.bz2: owncloud/core/l10n/nb_NO.php <==
<?php
$TRANSLATIONS = array(
"Expiration date is in the past." => "Utløpsdato er tilbake i tid.",
"Couldn't send mail to following users: %s " => "Klarte ikke å sende mail til følgende brukere: %s",
"Turned on maintenance mode" => "Slo på vedlikeholdsmodus",
"Turned off maintenance mode" => "Slo av vedlikeholdsmodus",
"Updated database" => "Oppdaterte databasen",
"Checked database schema update" => "Sjekket oppdatering av databaseskjema",
"Disabled incompatible apps: %s" => "Deaktiverte ukompatible apper: %s",
"No image or file provided" => "Bilde eller fil ikke angitt",
"Unknown filetype" => "Ukjent filtype",
"Invalid image" => "Ugyldig bilde",
"No temporary profile picture available, try again" => "Foreløpig profilbilde ikke tilgjengelig. Prøv igjen",
"No crop data provided" => "Ingen beskjæringsinformasjon angitt",
"Sunday" => "Søndag",
"Monday" => "Mandag",
"Tuesday" => "Tirsdag",
"Wednesday" => "Onsdag",
"Thursday" => "Torsdag",
"Friday" => "Fredag",
"Saturday" => "Lørdag",
"January" => "Januar",
"February" => "Februar",
"March" => "Mars",
"April" => "April",
"May" => "Mai",
"June" => "Juni",
"July" => "Juli",
"August" => "August",
"September" => "September",
"October" => "Oktober",
"November" => "November",
"December" => "Desember",
"Settings" => "Innstillinger",
"File" => "Fil",
"Folder" => "Mappe",
"Image" => "Bilde",
"Audio" => "Audio",
"Saving..." => "Lagrer...",
"seconds ago" => "for noen sekunder siden",
"_%n minute ago_::_%n minutes ago_" => array("for %n minutt siden","for %n minutter siden"),
"_%n hour ago_::_%n hours ago_" => array("for %n time siden","for %n timer siden"),
"today" => "i dag",
"yesterday" => "i går",
"_%n day ago_::_%n days ago_" => array("for %n dag siden","for %n dager siden"),
"last month" => "forrige måned",
"_%n month ago_::_%n months ago_" => array("for %n måned siden","for %n måneder siden"),
"last year" => "i fjor",
"years ago" => "årevis siden",
"Couldn't send reset email. Please contact your administrator." => "Klarte ikke å sende e-post for tilbakestilling. Kontakt administratoren.",
"The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." => "Lenken for tilbakestilling av passordet ditt er sendt til din e-postadresse. Hvis du ikke mottar den innen rimelig tid, sjekk mappen for søppelpost.<br>Hvis du ikke finner den der, kontakt din lokale administrator.",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" => "Filene dine er kryptert. Hvis du ikke har aktivert gjenopprettingsnøkkelen, vil det være helt umulig å få tilbake dataene dine etter at pasordet ditt er tilbakestilt.<br />Hvis du er usikker på hva du skal gjøre, kontakt administratoren din før du fortsetter. <br />Vil du virkelig fortsette?",
"I know what I'm doing" => "Jeg vet hva jeg gjør",
"Reset password" => "Tilbakestill passord",
"Password can not be changed. Please contact your administrator." => "Passordet kan ikke endres. Kontakt administratoren din.",
"Yes" => "Ja",
"No" => "Nei",
"Choose" => "Velg",
"Error loading file picker template: {error}" => "Feil ved lasting av filvelger-mal: {error}",
"Ok" => "Ok",
"Error loading message template: {error}" => "Feil ved lasting av meldingsmal: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} filkonflikt","{count} filkonflikter"),
"One file conflict" => "En filkonflikt",
"New Files" => "Nye filer",
"Already existing files" => "Allerede eksisterende filer",
"Which files do you want to keep?" => "Hvilke filer vil du beholde?",
"If you select both versions, the copied file will have a number added to its name." => "Hvis du velger begge versjonene vil den kopierte filen få et nummer lagt til i navnet.",
"Cancel" => "Avbryt",
"Continue" => "Fortsett",
"(all selected)" => "(alle valgt)",
"({count} selected)" => "({count} valgt)",
"Error loading file exists template" => "Feil ved lasting av \"filen eksisterer\"-mal",
"Very weak password" => "Veldig svakt passord",
"Weak password" => "Svakt passord",
"So-so password" => "So-so-passord",
"Good password" => "Bra passord",
"Strong password" => "Sterkt passord",
"Shared" => "Delt",
"Shared by {owner}" => "Delt av {owner}",
"Shared with {recipients}" => "Delt med {recipients}",
"Share" => "Del",
"Error" => "Feil",
"Error while sharing" => "Feil under deling",
"Error while unsharing" => "Feil ved oppheving av deling",
"Error while changing permissions" => "Feil ved endring av tillatelser",
"Shared with you and the group {group} by {owner}" => "Delt med deg og gruppen {group} av {owner}",
"Shared with you by {owner}" => "Delt med deg av {owner}",
"Share with user or group …" => "Del med bruker eller gruppe …",
"Share link" => "Del lenke",
"The public link will expire no later than {days} days after it is created" => "Den offentlige lenken vil utløpe senest {days} dager etter at den lages",
"By default the public link will expire after {days} days" => "Som standard vil den offentlige lenken utløpe etter {days} dager",
"Password protect" => "Passordbeskyttet",
"Choose a password for the public link" => "Velg et passord for den offentlige lenken",
"Allow Public Upload" => "Tillat Offentlig Opplasting",
"Email link to person" => "Email lenke til person",
"Send" => "Send",
"Set expiration date" => "Sett utløpsdato",
"Expiration date" => "Utløpsdato",
"Share via email:" => "Del på epost",
"No people found" => "Ingen personer funnet",
"group" => "gruppe",
"Resharing is not allowed" => "Videre deling er ikke tillatt",
"Shared in {item} with {user}" => "Delt i {item} med {user}",
"Unshare" => "Avslutt deling",
"notify by email" => "Varsle på email",
"can share" => "kan dele",
"can edit" => "kan endre",
"access control" => "tilgangskontroll",
"create" => "opprett",
"update" => "oppdatere",
"delete" => "slett",
"Password protected" => "Passordbeskyttet",
"Error unsetting expiration date" => "Feil ved nullstilling av utløpsdato",
"Error setting expiration date" => "Kan ikke sette utløpsdato",
"Sending ..." => "Sender...",
"Email sent" => "E-post sendt",
"Warning" => "Advarsel",
"The object type is not specified." => "Objekttypen er ikke spesifisert.",
"Enter new" => "Oppgi ny",
"Delete" => "Slett",
"Add" => "Legg til",
"Edit tags" => "Rediger merkelapper",
"Error loading dialog template: {error}" => "Feil ved lasting av dialogmal: {error}",
"No tags selected for deletion." => "Ingen merkelapper valgt for sletting.",
"Updating {productName} to version {version}, this may take a while." => "Oppdaterer {productName} til versjon {version}. Dette kan ta litt tid.",
"Please reload the page." => "Vennligst last siden på nytt.",
"The update was unsuccessful." => "Oppdateringen var vellykket.",
"The update was successful. Redirecting you to ownCloud now." => "Oppdateringen var vellykket. Du omdirigeres nå til ownCloud.",
"Couldn't reset password because the token is invalid" => "Klarte ikke å tilbakestille passordet fordi token er ugyldig.",
"Couldn't send reset email. Please make sure your username is correct." => "Klarte ikke å sende e-post for tilbakestilling av passord. Sjekk at brukernavnet ditt er korrekt.",
"Couldn't send reset email because there is no email address for this username. Please contact your administrator." => "Klarte ikke å sende e-post for tilbakestilling av passord fordi det ikke finnes noen e-postadresse for dette brukernavnet. Kontakt administratoren din.",
"%s password reset" => "%s tilbakestilling av passord",
"Use the following link to reset your password: {link}" => "Bruk følgende lenke for å tilbakestille passordet ditt: {link}",
"You will receive a link to reset your password via Email." => "Du burde motta detaljer om å tilbakestille passordet ditt via epost.",
"Username" => "Brukernavn",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" => "Filene dine er kryptert. Hvis du ikke har aktivert gjenopprettingsnøkkelen, vil det være helt umulig å få tilbake dataene dine etter at passordet ditt er tilbakestilt. Hvis du er usikker på hva du skal gjøre, kontakt administratoren din før du fortsetter. Vil du virkelig fortsette?",
"Yes, I really want to reset my password now" => "Ja, jeg vil virkelig tilbakestille passordet mitt nå",
"Reset" => "Tilbakestill",
"New password" => "Nytt passord",
"New Password" => "Nytt passord",
"Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " => "Mac OS X støttes ikke og %s vil ikke fungere korrekt på denne plattformen. Bruk på egen risiko!",
"For the best results, please consider using a GNU/Linux server instead." => "For beste resultat, vurder å bruke en GNU/Linux-server i stedet.",
"Personal" => "Personlig",
"Users" => "Brukere",
"Apps" => "Apper",
"Admin" => "Admin",
"Help" => "Hjelp",
"Error loading tags" => "Feil ved lasting av merkelapper",
"Tag already exists" => "Merkelappen finnes allerede",
"Error deleting tag(s)" => "Feil ved sletting av merkelapp(er)",
"Error tagging" => "Feil ved merking",
"Error untagging" => "Feil ved fjerning av merkelapp",
"Error favoriting" => "Feil ved favorittmerking",
"Error unfavoriting" => "Feil ved fjerning av favorittmerking",
"Access forbidden" => "Tilgang nektet",
"Cloud not found" => "Sky ikke funnet",
"Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" => "Hei der,\n\nbare informerer om at %s delte %s med deg.\nVis den: %s\n\n",
"The share will expire on %s." => "Delingen vil opphøre %s.",
"Cheers!" => "Ha det!",
"Security Warning" => "Sikkerhetsadvarsel",
"Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)" => "PHP-versjonen din er sårbar for NULL Byte attack (CVE-2006-7243)",
"Please update your PHP installation to use %s securely." => "Vennligst oppdater PHP-installasjonen din for å bruke %s på en sikker måte.",
"No secure random number generator is available, please enable the PHP OpenSSL extension." => "Ingen sikker slumptallsgenerator er tilgjengelig. Vennligst aktiver PHP OpenSSL-utvidelsen.",
"Without a secure random number generator an attacker may be able to predict password reset tokens and take over your account." => "Uten en sikker slumptallsgenerator er det mulig at en angriper kan forutse tokens for tilbakestilling av passord og ta over kontoen din.",
"Your data directory and files are probably accessible from the internet because the .htaccess file does not work." => "Datamappen og filene dine er sannsynligvis tilgjengelig fra Internett fordi .htaccess-filen ikke fungerer.",
"For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." => "For informasjon om hvordan du setter opp serveren din riktig, se <a href=\"%s\" target=\"_blank\">dokumentasjonen</a>.",
"Create an <strong>admin account</strong>" => "opprett en <strong>administrator-konto</strong>",
"Password" => "Passord",
"Storage & database" => "Lagring og database",
"Data folder" => "Datamappe",
"Configure the database" => "Konfigurer databasen",
"Only %s is available." => "Kun %s er tilgjengelig.",
"Database user" => "Databasebruker",
"Database password" => "Databasepassord",
"Database name" => "Databasenavn",
"Database tablespace" => "Database tabellområde",
"Database host" => "Databasevert",
"SQLite will be used as database. For larger installations we recommend to change this." => "SQLite vil bli brukt som database. For større installasjoner anbefaler vi å endre dette.",
"Finish setup" => "Fullfør oppsetting",
"Finishing …" => "Ferdigstiller ...",
"This application requires JavaScript to be enabled for correct operation.  Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and re-load this interface." => "Denne applikasjonen trenger JavaScript for å fungere korrekt.  Vennligst <a href=\"http://enable-javascript.com/\" target=\"_blank\">aktiver JavaScript</a> og last dette grensesnittet på nytt.",
"%s is available. Get more information on how to update." => "%s er tilgjengelig. Få mer informasjon om hvordan du kan oppdatere.",
"Log out" => "Logg ut",
"Automatic logon rejected!" => "Automatisk pålogging avvist!",
"If you did not change your password recently, your account may be compromised!" => "Hvis du ikke har endret passordet ditt nylig kan kontoen din være kompromitert",
"Please change your password to secure your account again." => "Vennligst skift passord for å gjøre kontoen din sikker igjen.",
"Server side authentication failed!" => "Autentisering feilet på serveren!",
"Please contact your administrator." => "Vennligst kontakt administratoren din.",
"Forgot your password? Reset it!" => "Glemt passordet ditt? Tilbakestill det!",
"remember" => "husk",
"Log in" => "Logg inn",
"Alternative Logins" => "Alternative innlogginger",
"Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" => "Hei der,<br><br>bare informerer om at %s delte <strong>%s</strong> med deg.<br><a href=\"%s\">Vis!</a><br><br>",
"This ownCloud instance is currently in single user mode." => "Denne ownCloud-instansen er for øyeblikket i enbrukermodus.",
"This means only administrators can use the instance." => "Dette betyr at kun administratorer kan bruke instansen.",
"Contact your system administrator if this message persists or appeared unexpectedly." => "Kontakt systemadministratoren hvis denne meldingen var uventet eller ikke forsvinner.",
"Thank you for your patience." => "Takk for din tålmodighet.",
"%s will be updated to version %s." => "%s vil bli oppdatert til versjon %s.",
"The following apps will be disabled:" => "Følgende apper vil bli deaktivert:",
"The theme %s has been disabled." => "Temaet %s har blitt deaktivert.",
"Please make sure that the database, the config folder and the data folder have been backed up before proceeding." => "Forsikre deg om at databasen, config-mappen og datamappen er blitt sikkerhetskopiert før du fortsetter.",
"Start update" => "Start oppdatering",
"This ownCloud instance is currently being updated, which may take a while." => "Denne ownCloud-instansen oppdateres for øyeblikket, noe som kan ta litt tid.",
"Please reload this page after a short time to continue using ownCloud." => "Vennligst last denne siden på nytt om en liten stund for å fortsette å bruke ownCloud."
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.13~dfsg.orig.tar.bz2: owncloud/core/l10n/nb_NO.php <==
<?php
$TRANSLATIONS = array(
"Expiration date is in the past." => "Utløpsdato er tilbake i tid.",
"Couldn't send mail to following users: %s " => "Klarte ikke å sende mail til følgende brukere: %s",
"Turned on maintenance mode" => "Slo på vedlikeholdsmodus",
"Turned off maintenance mode" => "Slo av vedlikeholdsmodus",
"Updated database" => "Oppdaterte databasen",
"Checked database schema update" => "Sjekket oppdatering av databaseskjema",
"Disabled incompatible apps: %s" => "Deaktiverte ukompatible apper: %s",
"No image or file provided" => "Bilde eller fil ikke angitt",
"Unknown filetype" => "Ukjent filtype",
"Invalid image" => "Ugyldig bilde",
"No temporary profile picture available, try again" => "Foreløpig profilbilde ikke tilgjengelig. Prøv igjen",
"No crop data provided" => "Ingen beskjæringsinformasjon angitt",
"Sunday" => "Søndag",
"Monday" => "Mandag",
"Tuesday" => "Tirsdag",
"Wednesday" => "Onsdag",
"Thursday" => "Torsdag",
"Friday" => "Fredag",
"Saturday" => "Lørdag",
"January" => "Januar",
"February" => "Februar",
"March" => "Mars",
"April" => "April",
"May" => "Mai",
"June" => "Juni",
"July" => "Juli",
"August" => "August",
"September" => "September",
"October" => "Oktober",
"November" => "November",
"December" => "Desember",
"Settings" => "Innstillinger",
"File" => "Fil",
"Folder" => "Mappe",
"Image" => "Bilde",
"Audio" => "Audio",
"Saving..." => "Lagrer...",
"seconds ago" => "for noen sekunder siden",
"_%n minute ago_::_%n minutes ago_" => array("for %n minutt siden","for %n minutter siden"),
"_%n hour ago_::_%n hours ago_" => array("for %n time siden","for %n timer siden"),
"today" => "i dag",
"yesterday" => "i går",
"_%n day ago_::_%n days ago_" => array("for %n dag siden","for %n dager siden"),
"last month" => "forrige måned",
"_%n month ago_::_%n months ago_" => array("for %n måned siden","for %n måneder siden"),
"last year" => "i fjor",
"years ago" => "årevis siden",
"Couldn't send reset email. Please contact your administrator." => "Klarte ikke å sende e-post for tilbakestilling. Kontakt administratoren.",
"The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." => "Lenken for tilbakestilling av passordet ditt er sendt til din e-postadresse. Hvis du ikke mottar den innen rimelig tid, sjekk mappen for søppelpost.<br>Hvis du ikke finner den der, kontakt din lokale administrator.",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" => "Filene dine er kryptert. Hvis du ikke har aktivert gjenopprettingsnøkkelen, vil det være helt umulig å få tilbake dataene dine etter at pasordet ditt er tilbakestilt.<br />Hvis du er usikker på hva du skal gjøre, kontakt administratoren din før du fortsetter. <br />Vil du virkelig fortsette?",
"I know what I'm doing" => "Jeg vet hva jeg gjør",
"Reset password" => "Tilbakestill passord",
"Password can not be changed. Please contact your administrator." => "Passordet kan ikke endres. Kontakt administratoren din.",
"Yes" => "Ja",
"No" => "Nei",
"Choose" => "Velg",
"Error loading file picker template: {error}" => "Feil ved lasting av filvelger-mal: {error}",
"Ok" => "Ok",
"Error loading message template: {error}" => "Feil ved lasting av meldingsmal: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} filkonflikt","{count} filkonflikter"),
"One file conflict" => "En filkonflikt",
"New Files" => "Nye filer",
"Already existing files" => "Allerede eksisterende filer",
"Which files do you want to keep?" => "Hvilke filer vil du beholde?",
"If you select both versions, the copied file will have a number added to its name." => "Hvis du velger begge versjonene vil den kopierte filen få et nummer lagt til i navnet.",
"Cancel" => "Avbryt",
"Continue" => "Fortsett",
"(all selected)" => "(alle valgt)",
"({count} selected)" => "({count} valgt)",
"Error loading file exists template" => "Feil ved lasting av \"filen eksisterer\"-mal",
"Very weak password" => "Veldig svakt passord",
"Weak password" => "Svakt passord",
"So-so password" => "So-so-passord",
"Good password" => "Bra passord",
"Strong password" => "Sterkt passord",
"Shared" => "Delt",
"Shared by {owner}" => "Delt av {owner}",
"Shared with {recipients}" => "Delt med {recipients}",
"Share" => "Del",
"Error" => "Feil",
"Error while sharing" => "Feil under deling",
"Error while unsharing" => "Feil ved oppheving av deling",
"Error while changing permissions" => "Feil ved endring av tillatelser",
"Shared with you and the group {group} by {owner}" => "Delt med deg og gruppen {group} av {owner}",
"Shared with you by {owner}" => "Delt med deg av {owner}",
"Share with user or group …" => "Del med bruker eller gruppe …",
"Share link" => "Del lenke",
"The public link will expire no later than {days} days after it is created" => "Den offentlige lenken vil utløpe senest {days} dager etter at den lages",
"By default the public link will expire after {days} days" => "Som standard vil den offentlige lenken utløpe etter {days} dager",
"Password protect" => "Passordbeskyttet",
"Choose a password for the public link" => "Velg et passord for den offentlige lenken",
"Allow Public Upload" => "Tillat Offentlig Opplasting",
"Email link to person" => "Email lenke til person",
"Send" => "Send",
"Set expiration date" => "Sett utløpsdato",
"Expiration date" => "Utløpsdato",
"Share via email:" => "Del på epost",
"No people found" => "Ingen personer funnet",
"group" => "gruppe",
"Resharing is not allowed" => "Videre deling er ikke tillatt",
"Shared in {item} with {user}" => "Delt i {item} med {user}",
"Unshare" => "Avslutt deling",
"notify by email" => "Varsle på email",
"can share" => "kan dele",
"can edit" => "kan endre",
"access control" => "tilgangskontroll",
"create" => "opprett",
"update" => "oppdatere",
"delete" => "slett",
"Password protected" => "Passordbeskyttet",
"Error unsetting expiration date" => "Feil ved nullstilling av utløpsdato",
"Error setting expiration date" => "Kan ikke sette utløpsdato",
"Sending ..." => "Sender...",
"Email sent" => "E-post sendt",
"Warning" => "Advarsel",
"The object type is not specified." => "Objekttypen er ikke spesifisert.",
"Enter new" => "Oppgi ny",
"Delete" => "Slett",
"Add" => "Legg til",
"Edit tags" => "Rediger merkelapper",
"Error loading dialog template: {error}" => "Feil ved lasting av dialogmal: {error}",
"No tags selected for deletion." => "Ingen merkelapper valgt for sletting.",
"Updating {productName} to version {version}, this may take a while." => "Oppdaterer {productName} til versjon {version}. Dette kan ta litt tid.",
"Please reload the page." => "Vennligst last siden på nytt.",
"The update was unsuccessful." => "Oppdateringen var vellykket.",
"The update was successful. Redirecting you to ownCloud now." => "Oppdateringen var vellykket. Du omdirigeres nå til ownCloud.",
"Couldn't reset password because the token is invalid" => "Klarte ikke å tilbakestille passordet fordi token er ugyldig.",
"Couldn't send reset email. Please make sure your username is correct." => "Klarte ikke å sende e-post for tilbakestilling av passord. Sjekk at brukernavnet ditt er korrekt.",
"Couldn't send reset email because there is no email address for this username. Please contact your administrator." => "Klarte ikke å sende e-post for tilbakestilling av passord fordi det ikke finnes noen e-postadresse for dette brukernavnet. Kontakt administratoren din.",
"%s password reset" => "%s tilbakestilling av passord",
"Use the following link to reset your password: {link}" => "Bruk følgende lenke for å tilbakestille passordet ditt: {link}",
"You will receive a link to reset your password via Email." => "Du burde motta detaljer om å tilbakestille passordet ditt via epost.",
"Username" => "Brukernavn",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" => "Filene dine er kryptert. Hvis du ikke har aktivert gjenopprettingsnøkkelen, vil det være helt umulig å få tilbake dataene dine etter at passordet ditt er tilbakestilt. Hvis du er usikker på hva du skal gjøre, kontakt administratoren din før du fortsetter. Vil du virkelig fortsette?",
"Yes, I really want to reset my password now" => "Ja, jeg vil virkelig tilbakestille passordet mitt nå",
"Reset" => "Tilbakestill",
"New password" => "Nytt passord",
"New Password" => "Nytt passord",
"Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " => "Mac OS X støttes ikke og %s vil ikke fungere korrekt på denne plattformen. Bruk på egen risiko!",
"For the best results, please consider using a GNU/Linux server instead." => "For beste resultat, vurder å bruke en GNU/Linux-server i stedet.",
"Personal" => "Personlig",
"Users" => "Brukere",
"Apps" => "Apper",
"Admin" => "Admin",
"Help" => "Hjelp",
"Error loading tags" => "Feil ved lasting av merkelapper",
"Tag already exists" => "Merkelappen finnes allerede",
"Error deleting tag(s)" => "Feil ved sletting av merkelapp(er)",
"Error tagging" => "Feil ved merking",
"Error untagging" => "Feil ved fjerning av merkelapp",
"Error favoriting" => "Feil ved favorittmerking",
"Error unfavoriting" => "Feil ved fjerning av favorittmerking",
"Access forbidden" => "Tilgang nektet",
"Cloud not found" => "Sky ikke funnet",
"Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" => "Hei der,\n\nbare informerer om at %s delte %s med deg.\nVis den: %s\n\n",
"The share will expire on %s." => "Delingen vil opphøre %s.",
"Cheers!" => "Ha det!",
"Security Warning" => "Sikkerhetsadvarsel",
"Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)" => "PHP-versjonen din er sårbar for NULL Byte attack (CVE-2006-7243)",
"Please update your PHP installation to use %s securely." => "Vennligst oppdater PHP-installasjonen din for å bruke %s på en sikker måte.",
"No secure random number generator is available, please enable the PHP OpenSSL extension." => "Ingen sikker slumptallsgenerator er tilgjengelig. Vennligst aktiver PHP OpenSSL-utvidelsen.",
"Without a secure random number generator an attacker may be able to predict password reset tokens and take over your account." => "Uten en sikker slumptallsgenerator er det mulig at en angriper kan forutse tokens for tilbakestilling av passord og ta over kontoen din.",
"Your data directory and files are probably accessible from the internet because the .htaccess file does not work." => "Datamappen og filene dine er sannsynligvis tilgjengelig fra Internett fordi .htaccess-filen ikke fungerer.",
"For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." => "For informasjon om hvordan du setter opp serveren din riktig, se <a href=\"%s\" target=\"_blank\">dokumentasjonen</a>.",
"Create an <strong>admin account</strong>" => "opprett en <strong>administrator-konto</strong>",
"Password" => "Passord",
"Storage & database" => "Lagring og database",
"Data folder" => "Datamappe",
"Configure the database" => "Konfigurer databasen",
"Only %s is available." => "Kun %s er tilgjengelig.",
"Database user" => "Databasebruker",
"Database password" => "Databasepassord",
"Database name" => "Databasenavn",
"Database tablespace" => "Database tabellområde",
"Database host" => "Databasevert",
"SQLite will be used as database. For larger installations we recommend to change this." => "SQLite vil bli brukt som database. For større installasjoner anbefaler vi å endre dette.",
"Finish setup" => "Fullfør oppsetting",
"Finishing …" => "Ferdigstiller ...",
"This application requires JavaScript to be enabled for correct operation.  Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and re-load this interface." => "Denne applikasjonen trenger JavaScript for å fungere korrekt.  Vennligst <a href=\"http://enable-javascript.com/\" target=\"_blank\">aktiver JavaScript</a> og last dette grensesnittet på nytt.",
"%s is available. Get more information on how to update." => "%s er tilgjengelig. Få mer informasjon om hvordan du kan oppdatere.",
"Log out" => "Logg ut",
"Automatic logon rejected!" => "Automatisk pålogging avvist!",
"If you did not change your password recently, your account may be compromised!" => "Hvis du ikke har endret passordet ditt nylig kan kontoen din være kompromitert",
"Please change your password to secure your account again." => "Vennligst skift passord for å gjøre kontoen din sikker igjen.",
"Server side authentication failed!" => "Autentisering feilet på serveren!",
"Please contact your administrator." => "Vennligst kontakt administratoren din.",
"Forgot your password? Reset it!" => "Glemt passordet ditt? Tilbakestill det!",
"remember" => "husk",
"Log in" => "Logg inn",
"Alternative Logins" => "Alternative innlogginger",
"Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" => "Hei der,<br><br>bare informerer om at %s delte <strong>%s</strong> med deg.<br><a href=\"%s\">Vis!</a><br><br>",
"This ownCloud instance is currently in single user mode." => "Denne ownCloud-instansen er for øyeblikket i enbrukermodus.",
"This means only administrators can use the instance." => "Dette betyr at kun administratorer kan bruke instansen.",
"Contact your system administrator if this message persists or appeared unexpectedly." => "Kontakt systemadministratoren hvis denne meldingen var uventet eller ikke forsvinner.",
"Thank you for your patience." => "Takk for din tålmodighet.",
"%s will be updated to version %s." => "%s vil bli oppdatert til versjon %s.",
"The following apps will be disabled:" => "Følgende apper vil bli deaktivert:",
"The theme %s has been disabled." => "Temaet %s har blitt deaktivert.",
"Please make sure that the database, the config folder and the data folder have been backed up before proceeding." => "Forsikre deg om at databasen, config-mappen og datamappen er blitt sikkerhetskopiert før du fortsetter.",
"Start update" => "Start oppdatering",
"This ownCloud instance is currently being updated, which may take a while." => "Denne ownCloud-instansen oppdateres for øyeblikket, noe som kan ta litt tid.",
"Please reload this page after a short time to continue using ownCloud." => "Vennligst last denne siden på nytt om en liten stund for å fortsette å bruke ownCloud.",
"To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" => "For å unngå tidsavbrudd ved store installasjoner, kan du i stedet kjøre følgende kommando fra installasjonsmappen:",
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
